@@ -1364,7 +1364,11 @@ pairPhiSTdist<-function(x,populations,nperm=0,negatives=FALSE,subset=NULL,showpr
         
         if(length(dpopu)>2)
         {
-            amo<-pegas::amova(distobj~dpopu,nperm=nperm,is.squared=TRUE)
+            
+            #use this temporary function until next update of the package pegas
+            amo<-pegas.amova(distobj~dpopu,nperm=nperm,is.squared=TRUE)
+            
+             # amo<-pegas::amova(distobj~dpopu,nperm=nperm,is.squared=TRUE)
             if(nperm>0)
             {
                 pmat[comb[2,i],comb[1,i]]<-amo$varcomp[1,2]
@@ -1593,10 +1597,194 @@ if(indels=="missing")
 
 
 
+#update amova
+#fix pegas::amova, use this temporary function until next update of pegas
+#Feb 28, 2020
 
-
-
-
+#temporary internal function pegas.amova
+pegas.amova<-function (formula, data = NULL, nperm = 1000, is.squared = FALSE)
+{
+    y.nms <- as.character(as.expression(formula[[2]]))
+    rhs <- formula[[3]]
+    gr.nms <- as.character(as.expression(rhs))
+    if (length(rhs) > 1)
+    gr.nms <- unlist(strsplit(gr.nms, "/"))
+    data.env <- if (is.null(data)) environment(formula) else as.environment(data)
+    if (any(sapply(gr.nms, function(x) !is.factor(get(x, envir = data.env)))))
+    warning("elements in the rhs of the formula are not all factors")
+    gr <- as.data.frame(sapply(gr.nms, get, envir = data.env),stringsAsFactors = TRUE)
+    y <- get(y.nms, envir = environment(formula))
+    if (any(is.na(y)))
+    warning("at least one missing value in the distance object.")
+    if (!is.squared)
+    y <- y^2
+    if (class(y) == "dist")
+    y <- as.matrix(y)
+    if (!is.matrix(y))
+    stop("the lhs of the formula must be either a matrix or an object of class 'dist'.")
+    n <- dim(y)[1]
+    Nlv <- length(gr)
+    if (nperm) {
+        o <- do.call("order", gr)
+        gr <- gr[o, , drop = FALSE]
+        if (Nlv > 1) {
+            f <- function(x) {
+                lp <- as.character(unique(x))
+                factor(match(as.character(x), lp))
+            }
+            for (i in 2:Nlv) gr[, i] <- f(gr[, i])
+        }
+        y <- y[o, o]
+    }
+    foo <- function(x, index) unlist(lapply(split(x, index),
+    sum))
+    getSSD <- function(y, gr, Nlv, N, n) {
+        SSD <- numeric(Nlv + 2)
+        SSD[Nlv + 2] <- sum(y/(2 * n))
+        for (i in 1:Nlv) {
+            p <- gr[, i]
+            SSD[i + 1] <- sum((y/(2 * N[[i]])[p])[outer(p, p,
+            "==")])
+        }
+        if (Nlv > 1)
+        for (i in 2:Nlv) SSD[i] <- SSD[i] - SSD[i + 1]
+        SSD[1] <- SSD[Nlv + 2] - sum(SSD[-(Nlv + 2)])
+        SSD
+    }
+    getDF <- function(gr, Nlv, N, n) {
+        df <- numeric(Nlv + 2)
+        df[1:Nlv] <- unlist(lapply(N, length))
+        df[Nlv + 1] <- n
+        for (i in (Nlv + 1):2) df[i] <- df[i] - df[i - 1]
+        df[1] <- df[1] - 1
+        df[Nlv + 2] <- n - 1
+        df
+    }
+    getNcoefficient <- function(gr, Nlv, N, n) {
+        Nig <- N[[Nlv]]
+        Nig2 <- Nig^2
+        npop <- length(Nig)
+        if (Nlv == 1)
+        ncoef <- (n - sum(Nig2)/n)/(npop - 1)
+        else {
+            if (Nlv == 2) {
+                ncoef <- numeric(3)
+                G <- nlevels(gr[, 1])
+                g <- gr[, 1][match(1:npop, as.integer(gr[, 2]))]
+                npopBYgr <- tabulate(g)
+                A <- sum(foo(Nig2, g)/foo(Nig, g))
+                ncoef[1] <- (n - A)/sum(npopBYgr - 1)
+                ncoef[2] <- (A - sum(Nig2)/n)/(G - 1)
+                ncoef[3] <- (n - sum(foo(Nig, g)^2/n))/(G - 1)
+            }
+            else {
+                ncoef <- numeric(Nlv + 1)
+                ncoef[Nlv] <- (n - sum(Nig2)/n)/(npop - 1)
+                ncoef[Nlv + 1] <- 1
+                for (i in 1:(Nlv - 1)) {
+                    group <- gr[, i]
+                    g <- group[match(1:npop, as.integer(gr[, i +
+                    1]))]
+                    A <- sum(foo(Nig, g)^2)/sum(foo(Nig, g))
+                    ncoef[i] <- (n - A)/(nlevels(group) - 1)
+                }
+            }
+        }
+        names(ncoef) <- letters[1:length(ncoef)]
+        ncoef
+    }
+    getVarComp <- function(MSD, Nlv, ncoef) {
+        if (Nlv == 1)
+        sigma2 <- c((MSD[1] - MSD[2])/ncoef, MSD[2])
+        else {
+            sigma2 <- numeric(Nlv + 1)
+            if (Nlv == 2) {
+                sigma2[3] <- MSD[3]
+                sigma2[2] <- (MSD[2] - sigma2[3])/ncoef[1]
+                sigma2[1] <- (MSD[1] - MSD[3] - ncoef[2] * sigma2[2])/ncoef[3]
+            }
+            else {
+                sigma2[Nlv + 1] <- MSD[Nlv + 1]
+                for (i in Nlv:1) {
+                    sel <- i:(Nlv + 1)
+                    sigma2[i] <- (MSD[i] - sum(ncoef[sel] * sigma2[sel]))/ncoef[i]
+                }
+            }
+        }
+        names(sigma2) <- c(names(gr), "Error")
+        sigma2
+    }
+    N <- lapply(gr, tabulate)
+    SSD <- getSSD(y, gr, Nlv, N, n)
+    df <- getDF(gr, Nlv, N, n)
+    MSD <- SSD/df
+    ncoef <- getNcoefficient(gr, Nlv, N, n)
+    sigma2 <- getVarComp(MSD, Nlv, ncoef)
+    res <- list(tab = data.frame(SSD = SSD, MSD = MSD, df = df,
+    row.names = c(names(gr), "Error", "Total"),stringsAsFactors = FALSE), varcoef = ncoef,
+    varcomp = sigma2, call = match.call())
+    class(res) <- "amova"
+    if (nperm) {
+        rSigma2 <- matrix(0, nperm, length(sigma2))
+        j <- if (Nlv == 1)
+        1:2
+        else Nlv + 1
+        for (i in 1:nperm) {
+            rY <- ape::perm.rowscols(y, n)
+            rSSD <- getSSD(rY, gr, Nlv, N, n)
+            rSigma2[i, j] <- getVarComp(rSSD/df, Nlv, ncoef)[j]
+        }
+        if (Nlv > 1) {
+            j <- Nlv
+            L <- lapply(levels(gr[, j - 1]), function(x) which(gr[,
+            j - 1] == x))
+            for (i in 1:nperm) {
+                rind <- unlist(lapply(L, sample))
+                rY <- y[rind, rind]
+                rSSD <- getSSD(rY, gr, Nlv, N, n)
+                rSigma2[i, j] <- getVarComp(rSSD/df, Nlv, ncoef)[j]
+            }
+            if (Nlv > 2) {
+                for (j in (Nlv - 1):2) {
+                    above <- gr[, j - 1]
+                    L <- lapply(levels(above), function(x) which(above ==
+                    x))
+                    for (i in 1:nperm) {
+                        rind <- integer(0)
+                        for (k in L) rind <- c(rind, sample(k))
+                        rind <- unlist(lapply(L, sample))
+                        rY <- y[rind, rind]
+                        rGR <- gr[rind, ]
+                        rN <- lapply(rGR, tabulate)
+                        rSSD <- getSSD(rY, rGR, Nlv, rN, n)
+                        rDF <- getDF(rGR, Nlv, rN, n)
+                        rNcoef <- getNcoefficient(rGR, Nlv, rN, n)
+                        rSigma2[i, j] <- getVarComp(rSSD/rDF, Nlv,
+                        rNcoef)[j]
+                    }
+                }
+            }
+            N2 <- N[[2]]
+            Higr <- gr[, 1][cumsum(N2)]
+            rGR <- gr
+            for (i in 1:nperm) {
+                rGR[, 1] <- unlist(mapply(rep, sample(Higr),
+                each = N2, SIMPLIFY = FALSE))
+                rN <- lapply(rGR, tabulate)
+                rSSD <- getSSD(rY, rGR, Nlv, rN, n)
+                rDF <- getDF(rGR, Nlv, rN, n)
+                rNcoef <- getNcoefficient(rGR, Nlv, rN, n)
+                rSigma2[i, 1] <- getVarComp(rSSD/rDF, Nlv, rNcoef)[1]
+            }
+        }
+        P <- numeric(Nlv + 1)
+        for (j in 1:(Nlv + 1)) P[j] <- sum(rSigma2[, j] >= sigma2[j])/(nperm +
+        1)
+        P[Nlv + 1] <- NA
+        res$varcomp <- data.frame(sigma2 = res$varcomp, P.value = P,stringsAsFactors = FALSE)
+    }
+    res
+}
 
 
 
